/*
* RFIDTest_v1.0 Used to verify RFID to MEGA is working like it should
* after uploading sketch open serial monitor and set baud rate to 115200 (lower right corner of serial monitor window)
* wave card next to RFID reader. Card specific number will be displayed.
* 
* last update 5-19-23 9:28 PM
* sda = 9 grn/brn
* sck = 52 grn
* mosi = 51 pink/grn
* miso = 50 pink/brn
* rq = nc
* gnd = gnd grey/brn
* rst = 53
* 3.3 = 3.3v red/brn
*/

#include <SPI.h>
#include <MFRC522.h>
#define SS_PIN 53 //sda
#define RST_PIN 9
byte readCard[4];
String tagID = ""; //string to be filled with read card Id numbers
MFRC522 mfrc522(SS_PIN, RST_PIN); // Create MFRC522 object

void setup()
{
  Serial.begin(115200);        // Initialize serial communications with the PC
  SPI.begin(); // SPI bus
  mfrc522.PCD_Init(); // Initialise MFRC522
  Serial.println("-------------------- RfidTest_V1.0--------------------------------");
  Serial.println("place card next to reader");
}//end of setup

void loop()
{
  //Wait until new tag is available
  while (readID())
  {
    Serial.print("Card ID # is ");
    Serial.println(tagID);
  }
}//end of loop

boolean readID() //read new tag is available
  {
    //Check if a new tag is detected or not. If not return.
    if ( ! mfrc522.PICC_IsNewCardPresent())
    {
      return false;
    }
    //Check if a new tag is readable or not. If not return.
    if ( ! mfrc522.PICC_ReadCardSerial())
    {
      return false;
    }
    tagID = "";
    // Read the 4 byte UID
    for ( uint8_t i = 0; i < 4; i++)
    {
      //readCard[i] = mfrc522.uid.uidByte[i];
      tagID.concat(String(mfrc522.uid.uidByte[i], HEX)); // Convert the UID to a single String
    }
    tagID.toUpperCase();
    mfrc522.PICC_HaltA(); // Stop reading
    return true;
  }//end of readID()
